==> haskell-crypton-conduit-0.2.3-211-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-9RGxJEJ7Nbn4T5d0hdB2cw
key:                  crypton-conduit-0.2.3-9RGxJEJ7Nbn4T5d0hdB2cw
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  a11243b42752ee6c5794fed852fbde2e
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-9RGxJEJ7Nbn4T5d0hdB2cw
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-JmvSlylEAqiI8LFhx2lxVp
    conduit-extra-1.3.8-IF1ZquB86eb2RrOex2bqoF
    crypton-1.0.4-HsWWtLvSQjKFYKNmIISx6y exceptions-0.10.7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    resourcet-1.2.6-6GDX0mNNFVQIZmMacsito5 transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-conduit-0.2.3-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-conduit
version:              0.2.3
visibility:           public
id:                   crypton-conduit-0.2.3-FLltqDALK2t4gLQWuQ0bfO
key:                  crypton-conduit-0.2.3-FLltqDALK2t4gLQWuQ0bfO
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Sibi Prabakaran <sibi@psibi.in>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/psibi/crypton-conduit
synopsis:             crypton conduit
description:
    Conduit bridge for crypton

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  5765f71674b0013bfe91bef618ff819a
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs:         /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/crypton-conduit-0.2.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-conduit
hs-libraries:         HScrypton-conduit-0.2.3-FLltqDALK2t4gLQWuQ0bfO
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    conduit-1.3.6.1-IACzArib6WtLejx9Lk1hSM
    conduit-extra-1.3.8-9QiDtjtytfa6eCoLtsLqkJ
    crypton-1.0.4-FZect82FX5O86IyFnZ6Ow6 exceptions-0.10.7
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5
    resourcet-1.2.6-HW1njfedMilBzSD7euG5nt transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-crypton-conduit/html/crypton-conduit.haddock

haddock-html:         /usr/share/doc/haskell-crypton-conduit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
